<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Masonite | Welcome</title>
  </head>
  <body>
    <h1>Hello Package World</h1>
    <p>
      This is a test project for developing your package:
      <strong>masonite-socialite</strong>
    </p>
    <div style="display: flex; flex-direction:column;">
      <a href="{{ route('auth.redirect', {'provider': 'github'}) }}">Connect with GitHub</a>
      <a href="{{ route('auth.redirect', {'provider': 'gitlab'}) }}">Connect with GitLab</a>
      <a href="{{ route('auth.redirect', {'provider': 'google'}) }}">Connect with Google</a>
      <a href="{{ route('auth.redirect', {'provider': 'facebook'}) }}">Connect with Facebook</a>
      <a href="{{ route('auth.redirect', {'provider': 'bitbucket'}) }}">Connect with BitBucket</a>
      <a href="{{ route('auth.redirect', {'provider': 'apple'}) }}">Connect with Apple</a>
    </div>
  </body>
</html>
